
/*
 * formatdef.c -- some defines for sbr/formatsbr.c
 *
 * $Id$
 */

#include <h/addrsbr.h>

int fmt_norm = AD_NAME;
